==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkQtTreeRingLabelMapper.java <==
// java wrapper for vtkQtTreeRingLabelMapper object
//

package vtk;
import vtk.*;

public class vtkQtTreeRingLabelMapper extends vtkLabeledDataMapper
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void RenderOpaqueGeometry_2(vtkViewport id0,vtkActor2D id1);
  public void RenderOpaqueGeometry(vtkViewport id0,vtkActor2D id1)
    { RenderOpaqueGeometry_2(id0,id1); }

  private native void RenderOverlay_3(vtkViewport id0,vtkActor2D id1);
  public void RenderOverlay(vtkViewport id0,vtkActor2D id1)
    { RenderOverlay_3(id0,id1); }

  private native long GetInputTree_4();
  public vtkTree GetInputTree() {
    long temp = GetInputTree_4();

    if (temp == 0) return null;
    return (vtkTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSectorsArrayName_5(String id0);
  public void SetSectorsArrayName(String id0)
    { SetSectorsArrayName_5(id0); }

  private native void SetLabelTextProperty_6(vtkTextProperty id0);
  public void SetLabelTextProperty(vtkTextProperty id0)
    { SetLabelTextProperty_6(id0); }

  private native long GetLabelTextProperty_7();
  public vtkTextProperty GetLabelTextProperty() {
    long temp = GetLabelTextProperty_7();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetLabelTextProperty_8(vtkTextProperty id0,int id1);
  public void SetLabelTextProperty(vtkTextProperty id0,int id1)
    { SetLabelTextProperty_8(id0,id1); }

  private native long GetLabelTextProperty_9(int id0);
  public vtkTextProperty GetLabelTextProperty(int id0) {
    long temp = GetLabelTextProperty_9(id0);

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetTextRotationArrayName_10(String id0);
  public void SetTextRotationArrayName(String id0)
    { SetTextRotationArrayName_10(id0); }

  private native String GetTextRotationArrayName_11();
  public String GetTextRotationArrayName()
    { return GetTextRotationArrayName_11(); }

  private native int GetMTime_12();
  public int GetMTime()
    { return GetMTime_12(); }

  private native void SetRenderer_13(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_13(id0); }

  private native long GetRenderer_14();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_14();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkQtTreeRingLabelMapper() { super(); }

  public vtkQtTreeRingLabelMapper(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-aarch64.pkg.tar.xz: vtk/vtkQtTreeRingLabelMapper.java <==
// java wrapper for vtkQtTreeRingLabelMapper object
//

package vtk;
import vtk.*;

public class vtkQtTreeRingLabelMapper extends vtkLabeledDataMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void RenderOpaqueGeometry_2(vtkViewport id0,vtkActor2D id1);
  public void RenderOpaqueGeometry(vtkViewport id0,vtkActor2D id1)
    { RenderOpaqueGeometry_2(id0,id1); }

  private native void RenderOverlay_3(vtkViewport id0,vtkActor2D id1);
  public void RenderOverlay(vtkViewport id0,vtkActor2D id1)
    { RenderOverlay_3(id0,id1); }

  private native long GetInputTree_4();
  public vtkTree GetInputTree() {
    long temp = GetInputTree_4();

    if (temp == 0) return null;
    return (vtkTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSectorsArrayName_5(String id0);
  public void SetSectorsArrayName(String id0)
    { SetSectorsArrayName_5(id0); }

  private native void SetLabelTextProperty_6(vtkTextProperty id0);
  public void SetLabelTextProperty(vtkTextProperty id0)
    { SetLabelTextProperty_6(id0); }

  private native long GetLabelTextProperty_7();
  public vtkTextProperty GetLabelTextProperty() {
    long temp = GetLabelTextProperty_7();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabelTextProperty_8(vtkTextProperty id0,int id1);
  public void SetLabelTextProperty(vtkTextProperty id0,int id1)
    { SetLabelTextProperty_8(id0,id1); }

  private native long GetLabelTextProperty_9(int id0);
  public vtkTextProperty GetLabelTextProperty(int id0) {
    long temp = GetLabelTextProperty_9(id0);

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTextRotationArrayName_10(String id0);
  public void SetTextRotationArrayName(String id0)
    { SetTextRotationArrayName_10(id0); }

  private native String GetTextRotationArrayName_11();
  public String GetTextRotationArrayName()
    { return GetTextRotationArrayName_11(); }

  private native int GetMTime_12();
  public int GetMTime()
    { return GetMTime_12(); }

  private native void SetRenderer_13(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_13(id0); }

  private native long GetRenderer_14();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_14();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkQtTreeRingLabelMapper() { super(); }

  public vtkQtTreeRingLabelMapper(long id) { super(id); }
  public native long   VTKInit();

}
